summaryrefslogtreecommitdiffstats
path: root/kmix/kmixapplet.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:46 -0600
commit27430f06c6cc2187c639f59f342f07f1fde91a8b (patch)
tree493c1095950b7f0a82690cedac1b749666be1b47 /kmix/kmixapplet.cpp
parent794a886cbd6d6893d62026f3800b95051652fc5a (diff)
downloadtdemultimedia-27430f06c6cc2187c639f59f342f07f1fde91a8b.tar.gz
tdemultimedia-27430f06c6cc2187c639f59f342f07f1fde91a8b.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kmix/kmixapplet.cpp')
-rw-r--r--kmix/kmixapplet.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmix/kmixapplet.cpp b/kmix/kmixapplet.cpp
index be672b2c..63b376e7 100644
--- a/kmix/kmixapplet.cpp
+++ b/kmix/kmixapplet.cpp
@@ -68,7 +68,7 @@ extern "C"
{
KDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
{
- KGlobal::locale()->insertCatalogue("kmix");
+ TDEGlobal::locale()->insertCatalogue("kmix");
return new KMixApplet(configFile, KPanelApplet::Normal,
parent, "kmixapplet");
}
@@ -77,8 +77,8 @@ extern "C"
int KMixApplet::s_instCount = 0;
//<Mixer> KMixApplet::Mixer::mixers();
-static const TQColor highColor = KGlobalSettings::baseColor();
-static const TQColor lowColor = KGlobalSettings::highlightColor();
+static const TQColor highColor = TDEGlobalSettings::baseColor();
+static const TQColor lowColor = TDEGlobalSettings::highlightColor();
static const TQColor backColor = "#000000";
static const TQColor mutedHighColor = "#FFFFFF";
static const TQColor mutedLowColor = "#808080";
@@ -172,7 +172,7 @@ KMixApplet::KMixApplet( const TQString& configFile, Type t,
s_instCount++;
kdDebug(67100) << "KMixApplet::KMixApplet instancing Applet, s_instCount="<< s_instCount << endl;
- KGlobal::dirs()->addResourceType( "appicon", KStandardDirs::kde_default("data") + "kmix/pics" );
+ TDEGlobal::dirs()->addResourceType( "appicon", KStandardDirs::kde_default("data") + "kmix/pics" );
loadConfig();
@@ -521,9 +521,9 @@ void KMixApplet::applyPreferences()
void KMixApplet::paletteChange ( const TQPalette &) {
if ( ! _customColors ) {
// We take over Colors from paletteChange(), if the user has not set custom colors.
- // ignore the given TQPalette and use the values from KGlobalSettings instead
- _colors.high = KGlobalSettings::highlightColor();
- _colors.low = KGlobalSettings::baseColor();
+ // ignore the given TQPalette and use the values from TDEGlobalSettings instead
+ _colors.high = TDEGlobalSettings::highlightColor();
+ _colors.low = TDEGlobalSettings::baseColor();
_colors.back = backColor;
setColors( _colors );
}